using System;
using Microsoft.SPOT;

using Microtoolskit.Hardware.Displays;

namespace AspirationCopeaux
{
    public class VisuAspiration
    {
        I2CLcd lcd;

        public VisuAspiration()
        {
            this.lcd = new I2CLcd(I2CLcd.LcdManufacturer.MIDAS, 100);
        }

        public VisuAspiration(I2CLcd lcd)
        {
            this.lcd = lcd;
        }

        // Rafrachissement du LCD
        private byte etatPostes = 0, etatPostes_1 = 1;
        private bool TP_1 = false, P_1 = false;

        /// <summary>
        /// Affichage des postes en service ou des messages d'erreur
        /// </summary>
        /// <param name="P1">Etat logique du poste 1</param>
        /// <param name="P2">Etat logique du poste 2</param>
        /// <param name="P3">Etat logique du poste 3</param>
        /// <param name="P4">Etat logique du poste 4</param>
        /// <param name="TP">Trmie pleine</param>
        /// <param name="P">Vide trop pouss</param>
        public void AfficheEtatPostes(bool P1, bool P2, bool P3, bool P4, bool TP, bool P)
        {
            etatPostes = CalculOctetEtatPostes(P1, P2, P3, P4);
            if ((etatPostes != etatPostes_1) || (TP_1 != TP) || (P_1 != P))
            {
                if (TP & P) { lcd.PutString(0, 1, "Vide et tremie  "); }
                else if (!TP & P) { lcd.PutString(0, 1, "Vide trop pousse"); }
                else if (TP & !P) { lcd.PutString(0, 1, "Tremie pleine   "); }
                else
                {
                    lcd.PutString(0, 1, "Aucun poste     ");
                    switch (etatPostes)
                    {
                        case 0: lcd.PutString(0, 1, "Aucun poste     "); break;
                        case 1: lcd.PutString(0, 1, "Poste 1         "); break;
                        case 2: lcd.PutString(0, 1, "Poste 2         "); break;
                        case 4: lcd.PutString(0, 1, "Poste 3         "); break;
                        case 8: lcd.PutString(0, 1, "Poste 4         "); break;
                        case 3: lcd.PutString(0, 1, "Poste1 et Poste2"); break;
                        case 5: lcd.PutString(0, 1, "Poste1 et Poste3"); break;
                        case 9: lcd.PutString(0, 1, "Poste1 et Poste4"); break;
                        case 6: lcd.PutString(0, 1, "Poste2 et Poste3"); break;
                        case 10: lcd.PutString(0, 1, "Poste2 et Poste4"); break;
                        case 12: lcd.PutString(0, 1, "Poste3 et Poste4"); break;
                        default: lcd.PutString(0, 1, "Non simulable   "); break;
                    }
                }
                etatPostes_1 = etatPostes; TP_1 = TP; P_1 = P;
            }
        }
        /// <summary>
        /// Conversion des bits P1,P2,P3,P4 en un octet P4 poids fort
        /// </summary>
        /// <param name="P1">Etat logique du poste 1</param>
        /// <param name="P2">Etat logique du poste 2</param>
        /// <param name="P3">Etat logique du poste 3</param>
        /// <param name="P4">Etat logique du poste 4</param>
        /// <returns></returns>
        private byte CalculOctetEtatPostes(bool P1, bool P2, bool P3, bool P4)
        {
            byte[] EtatP1 = BitConverter.GetBytes(P1);
            byte[] EtatP2 = BitConverter.GetBytes(P2);
            byte[] EtatP3 = BitConverter.GetBytes(P3);
            byte[] EtatP4 = BitConverter.GetBytes(P4);
            byte etat = (byte)(EtatP1[0] | (EtatP2[0] << 1) | (EtatP3[0] << 2) | (EtatP4[0] << 3));
            return etat;
        }
    }
}
